Signals that after serializing T, we can safely deserialize it as Self.
Signals that we can safely serialize Self in order to obtain a T on the other size.
Trait that allows zero-copy read of value-references from slices in LE format.
Trait that allows deserializing objects from a buffer.
Trait that allows zero-copy write of value-references to slices in LE format.
Most types will be encoded without any possibility of error.
The trait is used to provide these implementations.
This is currently not a substitute for implementing a proper NestedEncode.
Trait that allows appending bytes.
Used especially by the NestedEncode trait to output data.
Trait that allows zero-copy read of values from an underlying API in big endian format.
Trait that abstracts away an underlying API for a top-level object deserializer.
The underlying API can provide pre-parsed i64/u64 or pre-bundled boxed slices.
Most types will be encoded without any possibility of error.
The trait is used to provide these implementations.
This is currently not a substitute for implementing a proper TopEncode.
Specifies objects that can receive the result of a TopEncode computation.
in principle from NestedEncode performed on nested items.
Use to transfer objects from one generic type to another,
without the compiler being able to determine whether or not the two types are the same.
The cast is statically dispatched.